saclib: Computations with real algebraic numbers
================================================

Description
-----------

Saclib is a library of C programs for computer algebra derived from the
SAC2 system. It is mainly used as a dependency of qepcad.

License
-------

Saclib 2.2 Copyright (c) 1993, 2008, RISC-Linz (contact
wcbrown@usna.edu)

Permission to use, copy, modify, and/or distribute this software,
including source files, README files, etc., for any purpose with or
without fee is hereby granted, provided that the above copyright notice
and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.


Upstream Contact
----------------

-  Website: http://www.usna.edu/CS/qepcadweb/B/QEPCAD.html
-  Alternative location (sometimes more up-to-date):

   https://www.usna.edu/Users/cs/wcbrown/qepcad/B/QEPCAD.html

